# Startup Error Resolutions

## Database Connection Issue

```bash
Error connecting to the database : No servers found yet, Timeout: 2.0s, Topology Description: <TopologyDescription id: 66d182b1fb658ad1223aae5a, topology_type: Single, servers: [<ServerDescription ('act_database', 27017) server_type: Unknown, rtt: None>]>
```
To resolve this issue, you need to ensure that the database is properly started. To do this, you can use the following command:
```bash
docker-compose --profile dev up
```
If the database is already running, you can check that the connection URL in the `./Server/src/config/config.py` file is correct.  
To do this, make sure that the profile is configured in development mode:

```python
config = Config(Profile.DEV)
```

## ACME CSE Startup Issue
If you encounter issues starting ACME CSE, you can check that the configuration file is properly formatted.

```ini
[basic.config]
cseType=IN
cseID=id-in
cseName=cse-in
adminID=CAdmin
networkInterface=0.0.0.0
cseHost=${hostIPAddress}/acme
httpPort=8080
databaseType=memory
logLevel=debug
consoleTheme=dark

[cse.registration]
allowedCSROriginators=id-in,id-mn,id-asn

[textui]
startWithTUI=false

[cse]
enableSubscriptionVerificationRequests=false

[cse.operation.requests]
enable=true

[http]
enableUpperTesterEndpoint=true
enableStructureEndpoint=true
address=http://localhost:8080/acme
root=/acme
```

## ACME Connection Issue

```bash
HTTPConnectionPool(host='HOST', port=PORT): Max retries exceeded with url: /acme/cse-in (Caused by NewConnectionError('<urllib3.connection.HTTPConnection object at 0x7f4ba5d01c90>: Failed to establish a new connection: [Errno 111] Connection refused'))
```
If you encounter this issue, you need to ensure that the ACME service is properly started. To do this, you can use the following command:
```bash
cd acces/au/dossier/ACME
python -m acme
```
If the issue persists, check that the access URL is correctly formatted. To do this, verify the field in the `config.ini` file.
```ini
[http]
address=http://localhost:8080/acme
```
And try to connect to the following URL: `http://localhost:8080/acme/cse-in`

## ACME Request Error
If you encounter the error below, it means that the request sent to ACME is incorrect.

```json
{
    "m2m:dbg": "invalid arguments/attributes: request identifier parameter is mandatory in request"
}
```
Indeed, OneM2M requires different mandatory fields to make a request. To resolve this issue, please add the following headers:
```json
{
    "X-M2M-RVI": "3", 
    "X-M2M-Origin": "CAdmin",
    "X-M2M-RI": "153", 
}
```
To understand the meaning of these fields, you can refer to the ACME documentation [here](https://recipes.onem2m.org/introduction/What-are-oneM2M-Requests/#requests):

