# National Control Service Installation

## Overview
To simplify the application deployment, we use profiling: DEV is the profile for using local URLs, and PROD is the profile for production URLs (especially those for the Docker network).

## Cloning the Project
To begin, clone the project:

```bash
git clone git@gitlab.inria.fr:act/national-control-service.git 
cd national-control-service
```

## Activating the Virtual Environment

You can activate the virtual environment using the following command:

=== "Linux"
    ```bash
    python -m venv myenv
    source myenv/bin/activate
    ```
=== "Windows"
    ```bash
    python -m venv myenv
    myenv/Scripts/activate
    ```
=== "macOS"
    ```bash
    python -m venv myenv
    source myenv/bin/activate
    ```

If you name your virtual environment differently, you must add its name to the `.gitignore` file.

## Installing Dependencies
Once the virtual environment is activated, you can install the project dependencies:

```bash
pip install -r requirements.txt
```

## Database and MQTT Broker
There are different ways to start the MongoDB database. To simplify the application, it is recommended to use Docker.

If you want to use a local database, you will need to change the connection URL in the `./Server/src/config/config.py` file.

You can configure the MQTT broker (mosquitto) by creating the following directory structure:

```bash
cd ./national-control-service
mkdir -p ./mosquitto/config ./mosquitto/data ./mosquitto/log
```

Then, create a `mosquitto.conf` file in the `./mosquitto/config` folder with the following content:

```conf
persistence true
persistence_location /mosquitto/data/
log_dest file /mosquitto/log/mosquitto.log
listener 1883
allow_anonymous true
```

You can then start the dependencies with the following command:

```bash
docker-compose --profile dev up
```
This will start all the components of the Docker Compose linked to the "dev" profile.

## ACME CSE

After installing ACME, you can create a virtual environment:

=== "Linux"
    ```bash
    python -m venv myenv
    source myenv/bin/activate
    ```
=== "Windows"
    ```bash
    python -m venv myenv
    myenv/Scripts/activate
    ```
=== "macOS"
    ```bash
    python -m venv myenv
    source myenv/bin/activate
    ```

Then, install the dependencies with the following command:

```bash
pip install -r requirements.txt
```

On the first start of ACME, you will need to complete a configuration. You can follow the default options. Once the configuration is complete, go to the `acme.ini` file and copy the following configuration:

```ini  
[basic.config]
cseType=IN
cseID=id-in
cseName=cse-in
adminID=CAdmin
networkInterface=0.0.0.0
cseHost=${hostIPAddress}/acme
httpPort=8080
databaseType=memory
logLevel=debug
consoleTheme=dark

[cse.registration]
allowedCSROriginators=id-in,id-mn,id-asn

[textui]
startWithTUI=false

[cse]
enableSubscriptionVerificationRequests=false

[cse.operation.requests]
enable=true

[http]
enableUpperTesterEndpoint=true
enableStructureEndpoint=true
address=http://localhost:8080/acme
root=/acme
```

You can then start ACME with the following command:

```bash
python -m acme
```

You can access it via the address: `http://localhost:8080/acme`

## National Control Service
Once the prerequisites are installed, you can begin installing the project.

It is recommended to use a virtual environment to isolate the project dependencies. To do this, you can use `venv`, which is included in Python.

=== "Linux"
    ```bash
    python -m venv myenv
    source myenv/bin/activate
    ```
=== "Windows"
    ```bash
    python -m venv myenv
    myenv/Scripts/activate
    ```
=== "macOS"
    ```bash
    python -m venv myenv
    source myenv/bin/activate
    ```

Once the virtual environment is activated, you can install the project dependencies:

```bash
pip install -r requirements.txt
```

Once all dependencies are satisfied, you can start the National Control Service with the following command:

```bash
python -m Server
```

The server API is accessible via: `http://localhost:5000`  
You can change the server configuration by accessing the `./Server/src/config/config.py` file.

Once all components are started, you can verify that everything is working correctly by typing `#` in the ACME console, and you will see the following tree structure:

```
+ cse-in
|   +--AccessControlPolicy
|   +--acpCreateACPs
|   +--ApplicationEntity
|   +--CAdmin
|   // Default configurations above
|
|   // Configurations added below
|   +--ControlService
|   |  ...
|
|   +--DisplayApplication
|   |  ...
```

## Explanations

The National Control Service uses a MongoDB database hosted in a Docker container.  
ACME is the middleware used to communicate between the different components of the application. It cannot be hosted on Docker during the production phase because it must be possible to make incoming and outgoing requests via localhost.

For example, a component creates data that must notify localhost, but if ACME is hosted on Docker, it will notify the Docker container's IP address rather than localhost.
