# Development Environment
Here is the procedure to install the project locally.

## Prerequisites

To work on the project, you need to have an appropriate development environment. Here are the necessary prerequisites to work on the project:

- Git to clone the project. You can download it [here](https://git-scm.com/downloads).
- Python 3.11 or higher. You can download it [here](https://www.python.org/downloads/).
- Docker Desktop. You can download it [here](https://www.docker.com/products/docker-desktop).
- ACME CSE. You can download it: it is strongly recommended to use the GitHub repository to install ACME (manual installation) for greater customization. [here](https://acmecse.net).

## Connecting to the Private Gitlab Repository

To connect to the project, you need to ask Mr. Luigi Liquori to invite you to the ACT project. Once this is done, you can use an SSH key to connect to the private Gitlab repository.

=== "Linux"
    ```bash
    ssh-keygen 
    cat ~/.ssh/id_rsa.pub
    ```
=== "Windows"
    ```bash
    ssh-keygen
    type %USERPROFILE%\.ssh\id_rsa.pub
    ```
=== "macOS"
    ```bash
    ssh-keygen
    cat ~/.ssh/id_rsa.pub
    ```

Then, copy the generated SSH key and add it to your Gitlab profile. (Edit Profile > SSH Keys > Add SSH Key)

## Tips

It is strongly recommended to use a virtual environment to isolate the project's dependencies. To do this, you can use `venv`, which is included in Python.

Note: If you want to use a specific name for your virtual environment, you should add it to the `.gitignore` file.

=== "Linux"
    ```bash
    python -m venv myenv
    source myenv/bin/activate
    ```
=== "Windows"
    ```bash
    python -m venv myenv
    myenv/Scripts/activate
    ```
=== "macOS"
    ```bash
    python -m venv myenv
    source myenv/bin/activate
    ```

Once the virtual environment is activated, you can install the project's dependencies.

```bash
pip install -r requirements.txt
```

Once the prerequisites are installed, you can start developing the project. 
To begin, you can start the different components of the application:

- [National Control Service](../explanations/national-control-service/ncs-installation.md)
- [Local Service](../explanations/local-service/ls-installation.md)
- [ACT Library](./act-library.md)
