# Operation

## Architecture
The ACT project is divided into different components to follow the diagram described in the [technical specification document](https://inria.hal.science/hal-02989793/document).

### Diagram
![Diagram](./TS103757.diagramme.png)

### Components

In this diagram, you can see the different components of the application.

#### National Control Service
The National Control Service is the component responsible for managing the application's data. It consists of a MongoDB database and a Flask server.  
For simplicity, it is also the host for ACME and the MQTT Broker.

[See more](./national-control-service/explanations.md)

#### Local Service
The application is designed to allow the creation of multiple local services. A local service can be created by various entities (a company, a hospital, or even an individual).  
It can be divided into two parts:
- The Detection Service part, which is hosted on a local service
- The Local Service part, which consists of a Flask server.

Local services act as a gateway between the detection service and the National Control Service. They receive data from the detection service and send it to the National Control Service.

#### Detection Service
The Detection Service can be summarized in this proof of concept as a sensor. In the current state (version 1.0), it is simulated by a Python script that sends random data to the Local Service.

#### Peripheral Service
The peripheral service is comparable to a Wi-Fi network. It is linked to a detection service (which indicates if there are traces of COVID near the network). It can also be detected by phones.

#### Applications
There are two applications: mobile and web. They allow common users to see COVID-contaminated areas. The mobile application has an additional feature. It keeps a memory of nearby Wi-Fi networks, and once it makes a request to the National Control Service, it compares the nearby networks with those stored in the database. If the person was near a contaminated Wi-Fi network, they are notified.

#### Extensions
One of the future goals is to allow the National Control Service to exchange data with other National Control Services. This would help identify contamination zones in neighboring countries and could be implemented using an automatic routing system.

Inter-CSE routing is a feature of the oneM2M standard that is not yet available in version 3 but is planned for version 5.
